<?php
/**
 * camolin Theme Customizer
 *
 * @package camolin
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function camolin_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->get_setting( 'header_textcolor' )->transport = 'postMessage';

	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial(
			'blogname',
			array(
				'selector'        => '.site-title a',
				'render_callback' => 'camolin_customize_partial_blogname',
			)
		);

		$wp_customize->selective_refresh->add_partial(
			'blogdescription',
			array(
				'selector'        => '.site-description',
				'render_callback' => 'camolin_customize_partial_blogdescription',
			)
		);

		
	// adding copyright section to the camolin customizer 

	$wp_customize-> add_section('camolin_copyright_sec', array(
		'title'                    => __('Copyright','camolin'),
		'description' => __('Please, type here your copyright','camolin')
	));
	

	$wp_customize-> add_setting('camolin_copyright_set', array(
		'type'                     => 'theme_mod',
		'sanitize_callback'        => 'esc_attr'
	));

	$wp_customize-> add_control( 'camolin_ctrl_copyright', array(
		'label'                   => __('Copyright Information','camolin'),
		'description'             => __('Please, type your copyright here.','camolin'),
		'section'                 => 'camolin_copyright_sec',
		'settings'                => 'camolin_copyright_set',
		'type'                    => 'text'
	));
	
	}
}
add_action( 'customize_register', 'camolin_customize_register' );

/**
 * Render the site title for the selective refresh partial.
 *
 * @return void
 */
function camolin_customize_partial_blogname() {
	bloginfo( 'name' );
}

/**
 * Render the site tagline for the selective refresh partial.
 *
 * @return void
 */
function camolin_customize_partial_blogdescription() {
	bloginfo( 'description' );
}

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function camolin_customize_preview_js() {
	wp_enqueue_script( 'camolin-customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), camolin, true );
}
add_action( 'customize_preview_init', 'camolin_customize_preview_js' );
